from setuptools import setup, find_packages

setup(
    name='abandoned_tron',
    version='0.1',
    description='A library ',
    author='Knox26',
    author_email='knoxgaming7558@gmail.com',
    packages=find_packages(),
     classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)